# TOPSIS
It is a method of compensatory aggregation that compares a set of alternatives by identifying weights for each criterion, normalising scores for each criterion and calculating the geometric distance between each alternative and the ideal alternative, which is the best score in each criterion.

## How to Use this package

```
install the TOPSIS-Vaibhav-101803049 package

then install module from firstpackage import top
then run top(["filename","weight","impact","resultfile"])
```